@@ -1,8 +1,10 @@
+import dataclasses
 import datetime
 import inspect
 import json
 import mimetypes
 import re
+from enum import Enum
 from typing import Any, Callable, Dict, List, Optional, Type, TypeVar
 
 import pandas as pd
@@ -12,6 +14,8 @@ from pydantic.json import pydantic_encoder
 
 from streamlit_pydantic import schema_utils
 
+OVERWRITE_STREAMLIT_KWARGS_PREFIX = "st_kwargs_"
+
 
 def _name_to_title(name: str) -> str:
     """Converts a camelCase or snake_case name to title case."""
@@ -53,6 +57,12 @@ def _is_compatible_video(mime_type: str) -> bool:
     return mime_type in ["video/mp4"]
 
 
+class GroupOptionalFieldsStrategy(str, Enum):
+    NO = "no"
+    EXPANDER = "expander"
+    SIDEBAR = "sidebar"
+
+
 class InputUI:
     """Input UI renderer.
 
@@ -62,9 +72,11 @@ class InputUI:
     def __init__(
         self,
         key: str,
-        input_class: Type[BaseModel],
-        streamlit_container: st = st,
-        use_sidebar: bool = False,
+        model: Type[BaseModel],
+        streamlit_container: Any = st,
+        group_optional_fields: GroupOptionalFieldsStrategy = "no",  # type: ignore
+        lowercase_labels: bool = False,
+        ignore_empty_values: bool = False,
     ):
         self._key = key
 
@@ -78,14 +90,23 @@ class InputUI:
         if self._session_input_key not in st.session_state:
             self._session_state[self._session_input_key] = {}
 
-        self._input_class = input_class
-        self._use_sidebar = use_sidebar
+        self._lowercase_labels = lowercase_labels
+        self._group_optional_fields = group_optional_fields
         self._streamlit_container = streamlit_container
+        self._ignore_empty_values = ignore_empty_values
 
-        self._schema_properties = input_class.schema(by_alias=True).get(
+        if dataclasses.is_dataclass(model):
+            # Convert dataclasses
+            import pydantic
+
+            self._input_class = pydantic.dataclasses.dataclass(model).__pydantic_model__  # type: ignore
+        else:
+            self._input_class = model
+
+        self._schema_properties = self._input_class.schema(by_alias=True).get(
             "properties", {}
         )
-        self._schema_references = input_class.schema(by_alias=True).get(
+        self._schema_references = self._input_class.schema(by_alias=True).get(
             "definitions", {}
         )
 
@@ -104,70 +125,140 @@ class InputUI:
             "required", []
         )
 
+        properties_in_expander = []
+
         for property_key in self._schema_properties.keys():
-            if self._use_sidebar:
-                streamlit_app = self._streamlit_container.sidebar
-            else:
-                streamlit_app = self._streamlit_container
+            streamlit_app = self._streamlit_container
+            if property_key not in required_properties:
+                if self._group_optional_fields == "sidebar":
+                    streamlit_app = self._streamlit_container.sidebar
+                elif self._group_optional_fields == "expander":
+                    properties_in_expander.append(property_key)
+                    # Render properties later in expander (see below)
+                    continue
+
             property = self._schema_properties[property_key]
 
             if not property.get("title"):
                 # Set property key as fallback title
                 property["title"] = _name_to_title(property_key)
 
-            if property_key in required_properties:
-                streamlit_app = self._streamlit_container
-
             try:
-                self._store_value(
-                    property_key,
-                    self._render_property(streamlit_app, property_key, property),
-                )
+                value = self._render_property(streamlit_app, property_key, property)
+                if not self._is_value_ignored(property_key, value):
+                    self._store_value(property_key, value)
             except Exception:
                 pass
 
+        if properties_in_expander:
+            # Render optional properties in expander
+            with self._streamlit_container.expander(
+                "Optional Parameters", expanded=False
+            ):
+                for property_key in properties_in_expander:
+                    property = self._schema_properties[property_key]
+
+                    if not property.get("title"):
+                        # Set property key as fallback title
+                        property["title"] = _name_to_title(property_key)
+
+                    try:
+                        value = self._render_property(
+                            self._streamlit_container, property_key, property
+                        )
+
+                        if not self._is_value_ignored(property_key, value):
+                            self._store_value(property_key, value)
+
+                    except Exception:
+                        pass
+
         return self._session_state[self._session_input_key]
 
+    def _get_overwrite_streamlit_kwargs(self, key: str, property: Dict) -> Dict:
+
+        streamlit_kwargs: Dict = {}
+
+        for kwarg in property:
+            if kwarg.startswith(OVERWRITE_STREAMLIT_KWARGS_PREFIX):
+                streamlit_kwargs[
+                    kwarg.replace(OVERWRITE_STREAMLIT_KWARGS_PREFIX, "")
+                ] = property[kwarg]
+        return streamlit_kwargs
+
     def _get_default_streamlit_input_kwargs(self, key: str, property: Dict) -> Dict:
+        label = property.get("title")
+        if label and self._lowercase_labels:
+            label = label.lower()
+
         streamlit_kwargs = {
-            "label": property.get("title"),
+            "label": label,
             "key": str(self._session_state.run_id) + "-" + str(self._key) + "-" + key,
+            # "on_change": detect_change, -> not supported for inside forms
+            # "args": (key,),
         }
 
         if property.get("description"):
             streamlit_kwargs["help"] = property.get("description")
+        elif property.get("help"):
+            # Fallback to help. Used more frequently with dataclasses
+            streamlit_kwargs["help"] = property.get("help")
+
         return streamlit_kwargs
 
-    def _store_value(self, key: str, value: Any) -> None:
-        data_element = self._session_state[self._session_input_key]
-        key_elements = key.split(".")
-        for i, key_element in enumerate(key_elements):
-            if i == len(key_elements) - 1:
-                # add value to this element
-                data_element[key_element] = value
-                return
-            if key_element not in data_element:
-                data_element[key_element] = {}
-            data_element = data_element[key_element]
+    def _is_value_ignored(self, property_key: str, value: Any) -> bool:
+        """Returns `True` if the value should be ignored for storing in session.
 
-    def _get_value(self, key: str) -> Any:
-        data_element = self._session_state[self._session_input_key]
+        This is the case if `ignore_empty_values` is activated and the value is empty and not already set/changed before.
+        """
+        return (
+            self._ignore_empty_values
+            and (
+                type(value) == int or type(value) == float or isinstance(value, str)
+            )  # only for int, float or str
+            and not value
+            and self._get_value(property_key) is None
+        )
+
+    def _store_value_in_state(self, state: dict, key: str, value: Any) -> None:
         key_elements = key.split(".")
         for i, key_element in enumerate(key_elements):
             if i == len(key_elements) - 1:
                 # add value to this element
-                if key_element not in data_element:
+                state[key_element] = value
+                return
+            if key_element not in state:
+                state[key_element] = {}
+            state = state[key_element]
+
+    def _get_value_from_state(self, state: dict, key: str) -> Any:
+        key_elements = key.split(".")
+        for i, key_element in enumerate(key_elements):
+            if i == len(key_elements) - 1:
+                # add value to this element
+                if key_element not in state:
                     return None
-                return data_element[key_element]
-            if key_element not in data_element:
-                data_element[key_element] = {}
-            data_element = data_element[key_element]
+                return state[key_element]
+            if key_element not in state:
+                state[key_element] = {}
+            state = state[key_element]
         return None
 
+    def _store_value(self, key: str, value: Any) -> None:
+        return self._store_value_in_state(
+            self._session_state[self._session_input_key], key, value
+        )
+
+    def _get_value(self, key: str) -> Any:
+        return self._get_value_from_state(
+            self._session_state[self._session_input_key], key
+        )
+
     def _render_single_datetime_input(
-        self, streamlit_app: st, key: str, property: Dict
+        self, streamlit_app: Any, key: str, property: Dict
     ) -> Any:
         streamlit_kwargs = self._get_default_streamlit_input_kwargs(key, property)
+        overwrite_kwargs = self._get_overwrite_streamlit_kwargs(key, property)
 
         if property.get("format") == "time":
             if property.get("default"):
@@ -177,7 +268,7 @@ class InputUI:
                     )
                 except Exception:
                     pass
-            return streamlit_app.time_input(**streamlit_kwargs)
+            return streamlit_app.time_input(**{**streamlit_kwargs, **overwrite_kwargs})
         elif property.get("format") == "date":
             if property.get("default"):
                 try:
@@ -186,7 +277,7 @@ class InputUI:
                     )
                 except Exception:
                     pass
-            return streamlit_app.date_input(**streamlit_kwargs)
+            return streamlit_app.date_input(**{**streamlit_kwargs, **overwrite_kwargs})
         elif property.get("format") == "date-time":
             if property.get("default"):
                 try:
@@ -195,13 +286,13 @@ class InputUI:
                     )
                 except Exception:
                     pass
-            with self._streamlit_container.beta_container():
+            with self._streamlit_container.container():
                 self._streamlit_container.subheader(streamlit_kwargs.get("label"))
                 if streamlit_kwargs.get("description"):
                     self._streamlit_container.text(streamlit_kwargs.get("description"))
                 selected_date = None
                 selected_time = None
-                date_col, time_col = self._streamlit_container.beta_columns(2)
+                date_col, time_col = self._streamlit_container.columns(2)
                 with date_col:
                     date_kwargs = {"label": "Date", "key": key + "-date-input"}
                     if streamlit_kwargs.get("value"):
@@ -230,15 +321,22 @@ class InputUI:
             )
 
     def _render_single_file_input(
-        self, streamlit_app: st, key: str, property: Dict
+        self, streamlit_app: Any, key: str, property: Dict
     ) -> Any:
         streamlit_kwargs = self._get_default_streamlit_input_kwargs(key, property)
+        overwrite_kwargs = self._get_overwrite_streamlit_kwargs(key, property)
+
         file_extension = None
         if "mime_type" in property:
             file_extension = mimetypes.guess_extension(property["mime_type"])
 
         uploaded_file = streamlit_app.file_uploader(
-            **streamlit_kwargs, accept_multiple_files=False, type=file_extension
+            **{
+                **streamlit_kwargs,
+                "accept_multiple_files": False,
+                "type": file_extension,
+                **overwrite_kwargs,
+            }
         )
         if uploaded_file is None:
             return None
@@ -257,9 +355,10 @@ class InputUI:
         return bytes
 
     def _render_single_string_input(
-        self, streamlit_app: st, key: str, property: Dict
+        self, streamlit_app: Any, key: str, property: Dict
     ) -> Any:
         streamlit_kwargs = self._get_default_streamlit_input_kwargs(key, property)
+        overwrite_kwargs = self._get_overwrite_streamlit_kwargs(key, property)
 
         if property.get("default"):
             streamlit_kwargs["value"] = property.get("default")
@@ -271,28 +370,26 @@ class InputUI:
         if property.get("maxLength") is not None:
             streamlit_kwargs["max_chars"] = property.get("maxLength")
 
-        if (
-            property.get("format")
-            or (
-                property.get("maxLength") is not None
-                and int(property.get("maxLength")) < 140  # type: ignore
-            )
-            or property.get("writeOnly")
-        ):
-            # If any format is set, use single text input
-            # If max chars is set to less than 140, use single text input
-            # If write only -> password field
+        if property.get("readOnly"):
+            # Read only property -> only show value
+            streamlit_app.code(streamlit_kwargs["value"])
+            return streamlit_kwargs["value"]
+
+        if property.get("format") == "multi-line" and not property.get("writeOnly"):
+            # Use text area if format is multi-line (custom definition)
+            return streamlit_app.text_area(**{**streamlit_kwargs, **overwrite_kwargs})
+        else:
+            # Use text input for most situations
             if property.get("writeOnly"):
                 streamlit_kwargs["type"] = "password"
-            return streamlit_app.text_input(**streamlit_kwargs)
-        else:
-            # Otherwise use multiline text area
-            return streamlit_app.text_area(**streamlit_kwargs)
+            return streamlit_app.text_input(**{**streamlit_kwargs, **overwrite_kwargs})
 
     def _render_multi_enum_input(
-        self, streamlit_app: st, key: str, property: Dict
+        self, streamlit_app: Any, key: str, property: Dict
     ) -> Any:
         streamlit_kwargs = self._get_default_streamlit_input_kwargs(key, property)
+        overwrite_kwargs = self._get_overwrite_streamlit_kwargs(key, property)
+
         select_options: List[str] = []
         if property.get("items").get("enum"):  # type: ignore
             # Using Literal
@@ -310,13 +407,16 @@ class InputUI:
             except Exception:
                 pass
 
-        return streamlit_app.multiselect(**streamlit_kwargs, options=select_options)
+        return streamlit_app.multiselect(
+            **{**streamlit_kwargs, "options": select_options, **overwrite_kwargs}
+        )
 
     def _render_single_enum_input(
-        self, streamlit_app: st, key: str, property: Dict
+        self, streamlit_app: Any, key: str, property: Dict
     ) -> Any:
-
         streamlit_kwargs = self._get_default_streamlit_input_kwargs(key, property)
+        overwrite_kwargs = self._get_overwrite_streamlit_kwargs(key, property)
+
         select_options: List[str] = []
         if property.get("enum"):
             select_options = property.get("enum")  # type: ignore
@@ -335,10 +435,12 @@ class InputUI:
                 # Use default selection
                 pass
 
-        return streamlit_app.selectbox(**streamlit_kwargs, options=select_options)
+        return streamlit_app.selectbox(
+            **{**streamlit_kwargs, "options": select_options, **overwrite_kwargs}
+        )
 
     def _render_single_dict_input(
-        self, streamlit_app: st, key: str, property: Dict
+        self, streamlit_app: Any, key: str, property: Dict
     ) -> Any:
 
         # Add title and subheader
@@ -352,7 +454,7 @@ class InputUI:
         if not current_dict:
             current_dict = {}
 
-        key_col, value_col = streamlit_app.beta_columns(2)
+        key_col, value_col = streamlit_app.columns(2)
 
         with key_col:
             updated_key = streamlit_app.text_input(
@@ -375,8 +477,8 @@ class InputUI:
 
         streamlit_app.markdown("---")
 
-        with streamlit_app.beta_container():
-            clear_col, add_col = streamlit_app.beta_columns([1, 2])
+        with streamlit_app.container():
+            clear_col, add_col = streamlit_app.columns([1, 2])
 
             with clear_col:
                 if streamlit_app.button("Clear Items", key=key + "-clear-items"):
@@ -394,24 +496,61 @@ class InputUI:
         return current_dict
 
     def _render_single_reference(
-        self, streamlit_app: st, key: str, property: Dict
+        self, streamlit_app: Any, key: str, property: Dict
     ) -> Any:
         reference_item = schema_utils.get_single_reference_item(
             property, self._schema_references
         )
         return self._render_property(streamlit_app, key, reference_item)
 
-    def _render_multi_file_input(
-        self, streamlit_app: st, key: str, property: Dict
+    def _render_union_property(
+        self, streamlit_app: Any, key: str, property: Dict
     ) -> Any:
         streamlit_kwargs = self._get_default_streamlit_input_kwargs(key, property)
 
+        reference_items = schema_utils.get_union_references(
+            property, self._schema_references
+        )
+
+        name_reference_mapping: Dict[str, Dict] = {}
+
+        for reference in reference_items:
+            reference_title = _name_to_title(reference["title"])
+            name_reference_mapping[reference_title] = reference
+
+        streamlit_app.subheader(streamlit_kwargs["label"])  # type: ignore
+        if "help" in streamlit_kwargs:
+            streamlit_app.markdown(streamlit_kwargs["help"])
+
+        selected_reference = streamlit_app.selectbox(
+            key=streamlit_kwargs["key"],
+            label=streamlit_kwargs["label"] + " - Options",
+            options=name_reference_mapping.keys(),
+        )
+        input_data = self._render_object_input(
+            streamlit_app, key, name_reference_mapping[selected_reference]
+        )
+
+        streamlit_app.markdown("---")
+        return input_data
+
+    def _render_multi_file_input(
+        self, streamlit_app: Any, key: str, property: Dict
+    ) -> Any:
+        streamlit_kwargs = self._get_default_streamlit_input_kwargs(key, property)
+        overwrite_kwargs = self._get_overwrite_streamlit_kwargs(key, property)
+
         file_extension = None
         if "mime_type" in property:
             file_extension = mimetypes.guess_extension(property["mime_type"])
 
         uploaded_files = streamlit_app.file_uploader(
-            **streamlit_kwargs, accept_multiple_files=True, type=file_extension
+            **{
+                **streamlit_kwargs,
+                "accept_multiple_files": True,
+                "type": file_extension,
+                **overwrite_kwargs,
+            }
         )
         uploaded_files_bytes = []
         if uploaded_files:
@@ -420,18 +559,20 @@ class InputUI:
         return uploaded_files_bytes
 
     def _render_single_boolean_input(
-        self, streamlit_app: st, key: str, property: Dict
+        self, streamlit_app: Any, key: str, property: Dict
     ) -> Any:
         streamlit_kwargs = self._get_default_streamlit_input_kwargs(key, property)
+        overwrite_kwargs = self._get_overwrite_streamlit_kwargs(key, property)
 
         if property.get("default"):
             streamlit_kwargs["value"] = property.get("default")
-        return streamlit_app.checkbox(**streamlit_kwargs)
+        return streamlit_app.checkbox(**{**streamlit_kwargs, **overwrite_kwargs})
 
     def _render_single_number_input(
-        self, streamlit_app: st, key: str, property: Dict
+        self, streamlit_app: Any, key: str, property: Dict
     ) -> Any:
         streamlit_kwargs = self._get_default_streamlit_input_kwargs(key, property)
+        overwrite_kwargs = self._get_overwrite_streamlit_kwargs(key, property)
 
         number_transform = int
         if property.get("type") == "number":
@@ -476,11 +617,13 @@ class InputUI:
 
         if "min_value" in streamlit_kwargs and "max_value" in streamlit_kwargs:
             # TODO: Only if less than X steps
-            return streamlit_app.slider(**streamlit_kwargs)
+            return streamlit_app.slider(**{**streamlit_kwargs, **overwrite_kwargs})
         else:
-            return streamlit_app.number_input(**streamlit_kwargs)
+            return streamlit_app.number_input(
+                **{**streamlit_kwargs, **overwrite_kwargs}
+            )
 
-    def _render_object_input(self, streamlit_app: st, key: str, property: Dict) -> Any:
+    def _render_object_input(self, streamlit_app: Any, key: str, property: Dict) -> Any:
         properties = property["properties"]
         object_inputs = {}
         for property_key in properties:
@@ -490,13 +633,13 @@ class InputUI:
                 property["title"] = _name_to_title(property_key)
             # construct full key based on key parts -> required later to get the value
             full_key = key + "." + property_key
-            object_inputs[property_key] = self._render_property(
-                streamlit_app, full_key, property
-            )
+            value = self._render_property(streamlit_app, full_key, property)
+            if not self._is_value_ignored(property_key, value):
+                object_inputs[property_key] = value
         return object_inputs
 
     def _render_single_object_input(
-        self, streamlit_app: st, key: str, property: Dict
+        self, streamlit_app: Any, key: str, property: Dict
     ) -> Any:
         # Add title and subheader
         title = property.get("title")
@@ -510,7 +653,7 @@ class InputUI:
         return self._render_object_input(streamlit_app, key, object_reference)
 
     def _render_property_list_input(
-        self, streamlit_app: st, key: str, property: Dict
+        self, streamlit_app: Any, key: str, property: Dict
     ) -> Any:
 
         # Add title and subheader
@@ -538,8 +681,8 @@ class InputUI:
 
         streamlit_app.markdown("---")
 
-        with streamlit_app.beta_container():
-            clear_col, add_col = streamlit_app.beta_columns([1, 2])
+        with streamlit_app.container():
+            clear_col, add_col = streamlit_app.columns([1, 2])
 
             with clear_col:
                 if streamlit_app.button("Clear Items", key=key + "-clear-items"):
@@ -557,7 +700,7 @@ class InputUI:
         return current_list
 
     def _render_object_list_input(
-        self, streamlit_app: st, key: str, property: Dict
+        self, streamlit_app: Any, key: str, property: Dict
     ) -> Any:
 
         # TODO: support max_items, and min_items properties
@@ -580,8 +723,8 @@ class InputUI:
 
         streamlit_app.markdown("---")
 
-        with streamlit_app.beta_container():
-            clear_col, add_col = streamlit_app.beta_columns([1, 2])
+        with streamlit_app.container():
+            clear_col, add_col = streamlit_app.columns([1, 2])
 
             with clear_col:
                 if streamlit_app.button("Clear Items", key=key + "-clear-items"):
@@ -597,7 +740,7 @@ class InputUI:
         streamlit_app.write(current_list)
         return current_list
 
-    def _render_property(self, streamlit_app: st, key: str, property: Dict) -> Any:
+    def _render_property(self, streamlit_app: Any, key: str, property: Dict) -> Any:
         if schema_utils.is_single_enum_property(property, self._schema_references):
             return self._render_single_enum_input(streamlit_app, key, property)
 
@@ -637,6 +780,9 @@ class InputUI:
         if schema_utils.is_single_reference(property):
             return self._render_single_reference(streamlit_app, key, property)
 
+        if schema_utils.is_union_property(property):
+            return self._render_union_property(streamlit_app, key, property)
+
         streamlit_app.warning(
             "The type of the following property is currently not supported: "
             + str(property.get("title"))
@@ -668,7 +814,7 @@ class OutputUI:
             # st.json(jsonable_encoder(self._output_data))
 
     def _render_single_text_property(
-        self, streamlit: st, property_schema: Dict, value: Any
+        self, streamlit: Any, property_schema: Dict, value: Any
     ) -> None:
         # Add title and subheader
         streamlit.subheader(property_schema.get("title"))
@@ -680,7 +826,7 @@ class OutputUI:
             streamlit.code(str(value), language="plain")
 
     def _render_single_file_property(
-        self, streamlit: st, property_schema: Dict, value: Any
+        self, streamlit: Any, property_schema: Dict, value: Any
     ) -> None:
         # Add title and subheader
         streamlit.subheader(property_schema.get("title"))
@@ -720,7 +866,7 @@ class OutputUI:
             )
 
     def _render_single_complex_property(
-        self, streamlit: st, property_schema: Dict, value: Any
+        self, streamlit: Any, property_schema: Dict, value: Any
     ) -> None:
         # Add title and subheader
         streamlit.subheader(property_schema.get("title"))
@@ -729,7 +875,7 @@ class OutputUI:
 
         streamlit.json(json.dumps(value, default=pydantic_encoder))
 
-    def _render_single_output(self, streamlit: st, output_data: BaseModel) -> None:
+    def _render_single_output(self, streamlit: Any, output_data: BaseModel) -> None:
         try:
             if _has_output_ui_renderer(output_data):
                 if _function_has_named_arg(output_data.render_output_ui, "input"):  # type: ignore
@@ -818,7 +964,7 @@ class OutputUI:
         # TODO: Fallback to json output
         # streamlit.json(jsonable_encoder(output_data))
 
-    def _render_list_output(self, streamlit: st, output_data: List) -> None:
+    def _render_list_output(self, streamlit: Any, output_data: List) -> None:
         try:
             data_items: List = []
             for data_item in output_data:
@@ -837,21 +983,31 @@ class OutputUI:
 
 def pydantic_input(
     key: str,
-    input_class: Type[BaseModel],
-    use_sidebar: bool = False,
+    model: Type[BaseModel],
+    group_optional_fields: GroupOptionalFieldsStrategy = "no",  # type: ignore
+    lowercase_labels: bool = False,
+    ignore_empty_values: bool = False,
 ) -> Dict:
     """Auto-generates input UI elements for a selected Pydantic class.
 
     Args:
         key (str): A string that identifies the form. Each form must have its own key.
-        input_class (Type[BaseModel]): The input class (based on Pydantic BaseModel).
-        use_sidebar (bool, optional): If `True`, optional input elements will be rendered on the sidebar.
+        model (Type[BaseModel]): The input model. Either a class or instance based on Pydantic `BaseModel` or Python `dataclass`.
+        group_optional_fields (str, optional): If `sidebar`, optional input elements will be rendered on the sidebar.
+            If `expander`,  optional input elements will be rendered inside an expander element. Defaults to `no`.
+        lowercase_labels (bool): If `True`, all input element labels will be lowercased. Defaults to `False`.
+        ignore_empty_values (bool): If `True`, empty values for strings and numbers will not be stored in the session state. Defaults to `False`.
 
     Returns:
         Dict: A dictionary with the current state of the input data.
     """
-
-    return InputUI(key, input_class, use_sidebar=use_sidebar).render_ui()
+    return InputUI(
+        key,
+        model,
+        group_optional_fields=group_optional_fields,
+        lowercase_labels=lowercase_labels,
+        ignore_empty_values=ignore_empty_values,
+    ).render_ui()
 
 
 def pydantic_output(output_data: Any) -> None:
@@ -870,17 +1026,24 @@ T = TypeVar("T", bound=BaseModel)
 
 def pydantic_form(
     key: str,
-    input_class: Type[T],
+    model: Type[T],
     submit_label: str = "Submit",
     clear_on_submit: bool = False,
+    group_optional_fields: GroupOptionalFieldsStrategy = "no",  # type: ignore
+    lowercase_labels: bool = False,
+    ignore_empty_values: bool = False,
 ) -> Optional[T]:
     """Auto-generates a Streamlit form based on the given (Pydantic-based) input class.
 
     Args:
         key (str): A string that identifies the form. Each form must have its own key.
-        input_class (Type[BaseModel]): The input class (based on Pydantic BaseModel).
+        model (Type[BaseModel]): The input model. Either a class or instance based on Pydantic `BaseModel` or Python `dataclass`.
         submit_label (str): A short label explaining to the user what this button is for. Defaults to “Submit”.
         clear_on_submit (bool): If True, all widgets inside the form will be reset to their default values after the user presses the Submit button. Defaults to False.
+        group_optional_fields (str, optional): If `sidebar`, optional input elements will be rendered on the sidebar.
+            If `expander`,  optional input elements will be rendered inside an expander element. Defaults to `no`.
+        lowercase_labels (bool): If `True`, all input element labels will be lowercased. Defaults to `False`.
+        ignore_empty_values (bool): If `True`, empty values for strings and numbers will not be stored in the session state. Defaults to `False`.
 
     Returns:
         Optional[BaseModel]: An instance of the given input class,
@@ -888,12 +1051,18 @@ def pydantic_form(
     """
 
     with st.form(key=key, clear_on_submit=clear_on_submit):
-        input_state = pydantic_input(key, input_class, use_sidebar=False)
+        input_state = pydantic_input(
+            key,
+            model,
+            group_optional_fields=group_optional_fields,
+            lowercase_labels=lowercase_labels,
+            ignore_empty_values=ignore_empty_values,
+        )
         submit_button = st.form_submit_button(label=submit_label)
 
         if submit_button:
             try:
-                return parse_obj_as(input_class, input_state)
+                return parse_obj_as(model, input_state)
             except ValidationError as ex:
                 error_text = "**Whoops! There were some problems with your input:**"
                 for error in ex.errors():
